<?php
/**
 * @file
 * Theme and preprocess functions for the Election Candidate module.
 */

/**
 * Process variables for election-candidate.tpl.php.
 *
 * The $variables array contains the following arguments:
 * - $candidate
 * - $election
 * - $view_mode
 * - $page
 *
 * @see election-candidate.tpl.php
 */
function template_preprocess_election_candidate(&$variables) {
  $variables['view_mode'] = $variables['elements']['#view_mode'];

  $variables['teaser'] = $variables['view_mode'] == 'teaser';
  $variables['details'] = $variables['view_mode'] == 'details';
  $variables['page'] = ($variables['view_mode'] == 'full' || $variables['view_mode'] == 'details');

  $variables['election'] = $variables['elements']['#election'];
  $variables['candidate'] = $variables['elements']['#candidate'];
  $variables['post'] = $variables['elements']['#post'];

  $election = $variables['election'];
  $candidate = $variables['candidate'];
  $post = $variables['post'];
  $election_type = _election_type_get_info($election->type);

  if (empty($post)) {
    // Handle gracefully when the candidate's post is deleted prematurely.
    $post = entity_get_controller('election_post')->create(array(
      'type' => $election_type['post machine name'],
    ));
  }

  $uri = election_candidate_uri($candidate);
  $variables['url'] = url($uri['path'], $uri['options']);

  $election_uri = entity_uri('election', $election);
  $variables['election_url'] = url($election_uri['path'], $election_uri['options']);
  $variables['election_title'] = check_plain($election->title);
  $variables['election_link'] = l($election->title, $election_uri['path'], $election_uri['options']);
  $variables['election_type'] = check_plain($election_type['name']);

  $post_uri = entity_uri('election_post', $post);
  $variables['post_url'] = url($post_uri['path'], $post_uri['options']);
  $variables['post_title'] = check_plain($post->title);
  $variables['post_link'] = l($post->title, $post_uri['path'], $post_uri['options']);
  $variables['post_name'] = check_plain($election_type['post name']);

  $variables['full_name'] = t('@first_name @last_name', array('@first_name' => $candidate->first_name, '@last_name' => $candidate->last_name));

  $variables += array('content' => array());

  $variables['content']['election'] = array(
    '#theme' => 'election_info_item',
    '#label' => t('Election'),
    '#value' => $variables['election_link'],
    '#html' => TRUE,
  );

  $variables['content']['post'] = array(
    '#theme' => 'election_info_item',
    '#label' => t('Standing for'),
    '#value' => $variables['post_link'],
    '#html' => TRUE,
  );

  if ($variables['view_mode'] == 'details') {

    $variables['username'] = theme('username', array('account' => $candidate->uid ? user_load($candidate->uid) : NULL));
    $variables['mail'] = l($candidate->mail, 'mailto:' . $candidate->mail, array('absolute' => TRUE));

    $variables['content']['mail'] = array(
      '#theme' => 'election_info_item',
      '#label' => t('Email address'),
      '#value' => $variables['mail'],
      '#html' => TRUE,
    );

    $variables['content']['candidate-username'] = array(
      '#theme' => 'election_info_item',
      '#label' => t('Username'),
      '#value' => $variables['username'],
      '#html' => TRUE,
    );

  }

  foreach (element_children($variables['elements']) as $key) {
    $variables['content'][$key] = $variables['elements'][$key];
  }

  // Make the field variables available with the appropriate language.
  field_attach_preprocess('election_candidate', $candidate, $variables['content'], $variables);

  $variables['classes_array'][] = drupal_html_class('election-' . $election->type . '-candidate');

  $variables['theme_hook_suggestions'][] = 'election_candidate__' . $candidate->candidate_id;
  $variables['theme_hook_suggestions'][] = 'election__' . $election->type . '__candidate';
  $variables['theme_hook_suggestions'][] = 'election__' . $election->election_id . '__candidate';

}

/**
 * Theme function for displaying a candidate's full name.
 */
function theme_election_candidate_full_name($variables) {
  $candidate = $variables['candidate'];
  return check_plain($candidate->first_name . ' ' . $candidate->last_name);
}

/**
 * Theme function for displaying a candidate as an item on a ballot form.
 */
function theme_election_candidate_ballot_item($variables) {
  $candidate = $variables['candidate'];
  return '<span class="election-candidate-ballot-item">' . l(theme('election_candidate_full_name', array('candidate' => $candidate)), election_candidate_uri_path($candidate)) . '</span>';
}
